@@ -10,7 +10,7 @@
 # ABSTRACT: Check the configuration of an application
 
 package App::Cme::Command::check ;
-$App::Cme::Command::check::VERSION = '1.020';
+$App::Cme::Command::check::VERSION = '1.021';
 use strict;
 use warnings;
 use 5.10.1;
@@ -40,7 +40,7 @@ sub opt_spec {
 sub usage_desc {
   my ($self) = @_;
   my $desc = $self->SUPER::usage_desc; # "%c COMMAND %o"
-  return "$desc [application]  [ config_file | ~~ ]";
+  return "$desc [application]  [ config_file ]";
 }
 
 sub description {
@@ -88,7 +88,7 @@ App::Cme::Command::check - Check the configuration of an application
 
 =head1 VERSION
 
-version 1.020
+version 1.021
 
 =head1 SYNOPSIS
 
