@@ -10,7 +10,7 @@
 # ABSTRACT: Dump the configuration of an application
 
 package App::Cme::Command::dump ;
-$App::Cme::Command::dump::VERSION = '1.020';
+$App::Cme::Command::dump::VERSION = '1.021';
 use strict;
 use warnings;
 use 5.10.1;
@@ -56,7 +56,7 @@ sub opt_spec {
 sub usage_desc {
   my ($self) = @_;
   my $desc = $self->SUPER::usage_desc; # "%c COMMAND %o"
-  return "$desc [application]  [ config_file | ~~ ] [ -dumptype full|custom ] [ path ]";
+  return "$desc [application]  [ config_file ] [ -dumptype full|custom ] [ path ]";
 }
 
 sub description {
@@ -104,7 +104,7 @@ App::Cme::Command::dump - Dump the configuration of an application
 
 =head1 VERSION
 
-version 1.020
+version 1.021
 
 =head1 SYNOPSIS
 
