@@ -10,7 +10,7 @@
 # ABSTRACT: Search the configuration of an application
 
 package App::Cme::Command::search ;
-$App::Cme::Command::search::VERSION = '1.020';
+$App::Cme::Command::search::VERSION = '1.021';
 use strict;
 use warnings;
 use 5.10.1;
@@ -46,7 +46,7 @@ sub opt_spec {
 sub usage_desc {
   my ($self) = @_;
   my $desc = $self->SUPER::usage_desc; # "%c COMMAND %o"
-  return "$desc [application]  [ config_file | ~~ ] -search xxx [ -narrow-search ... ] " ;
+  return "$desc [application]  [ config_file ] -search xxx [ -narrow-search ... ] " ;
 }
 
 sub description {
@@ -86,7 +86,7 @@ App::Cme::Command::search - Search the configuration of an application
 
 =head1 VERSION
 
-version 1.020
+version 1.021
 
 =head1 SYNOPSIS
 
