@@ -10,7 +10,7 @@
 #ABSTRACT: Common methods for App::Cme
 
 package App::Cme::Common;
-$App::Cme::Common::VERSION = '1.020';
+$App::Cme::Common::VERSION = '1.021';
 use strict;
 use warnings;
 use 5.10.1;
@@ -23,6 +23,8 @@ use Scalar::Util qw/blessed/;
 use Path::Tiny;
 use Encode qw(decode_utf8);
 
+my @store;
+
 sub cme_global_options {
   my ( $class, $app ) = @_;
 
@@ -144,7 +146,11 @@ sub model {
     $cm_args{model_dir} = $opt->{model_dir} if $opt->{model_dir};
     $cm_args{log_level} = $log_level if $log_level;
 
-    return $self->{_model} ||= Config::Model->new( %cm_args );
+    if (not $self->{_model}) {
+        my $model = $self->{_model} = Config::Model->new( %cm_args );
+        push @store, $model;
+    }
+    return $self->{_model};
 }
 
 sub instance {
@@ -258,7 +264,7 @@ App::Cme::Common - Common methods for App::Cme
 
 =head1 VERSION
 
-version 1.020
+version 1.021
 
 =head1 SYNOPSIS
 
